==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/nl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Te doen",
    "Personal" : "Persoonlijk",
    "{actor} created calendar {calendar}" : "{actor} creëerde agenda {calendar}",
    "You created calendar {calendar}" : "Jij creëerde agenda {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} verwijderde agenda {calendar}",
    "You deleted calendar {calendar}" : "Je verwijderde agenda {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} werkte agenda {calendar} bij",
    "You updated calendar {calendar}" : "Je werkte agenda {calendar} bij",
    "You shared calendar {calendar} as public link" : "Je deelde de agenda {calendar} als openbare link",
    "You removed public link for calendar {calendar}" : "Je verwijderde de openbare link voor de agenda {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} deelde agenda {calendar} met je",
    "You shared calendar {calendar} with {user}" : "Je deelde agenda {calendar} met {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} deelde agenda {calendar} met {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} is gestop de agenda {calendar} met je te delen",
    "You unshared calendar {calendar} from {user}" : "Je stopte met delen agenda {calendar} met {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} stopte met delen agenda {calendar} met {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} stopte het delen van agenda {calendar} met zichzelf",
    "You shared calendar {calendar} with group {group}" : "Je deelde agenda {calendar} met groep {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} deelde agenda {calendar} met groep {group}",
    "You unshared calendar {calendar} from group {group}" : "Je stopte het delen van agenda {calendar} met groep {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} stopte het delen van agenda {calendar} met groep {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creëerde afspraak {event} in agenda {calendar}",
    "You created event {event} in calendar {calendar}" : "Je creëerde afspraak {event} in agenda {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} verwijderde afspraak {event} uit agenda {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Je verwijderde afspraak {event} uit agenda {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} heeft afspraak {event} in agenda {calendar} bijgewerkt",
    "You updated event {event} in calendar {calendar}" : "Je hebt afspraak {event} in agenda {calendar} bijgewerkt",
    "Busy" : "Bezig",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creëerde taak {todo} in lijst {calendar}",
    "You created todo {todo} in list {calendar}" : "Jij creëerde taak {todo} in lijst {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} heeft de taak {todo} uit lijst {calendar} verwijderd",
    "You deleted todo {todo} from list {calendar}" : "Je verwijderde taak {todo} uit lijst {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} heeft taak {todo} bijgewerkt in lijst {calendar}",
    "You updated todo {todo} in list {calendar}" : "Je hebt taak {todo} bijgewerkt in lijst {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} heeft taak {todo} in lijst {calendar} afgewerkt",
    "You solved todo {todo} in list {calendar}" : "Je hebt taak {todo} in lijst {calendar} afgewerkt",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} heropende taak {todo} in lijst {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Je heropende taak {todo} in lijst {calendar}",
    "Calendar and tasks" : "Agenda en taken",
    "A <strong>calendar</strong> was modified" : "Een <strong>agenda</strong> is aangepast",
    "A calendar <strong>event</strong> was modified" : "Een agenda <strong>gebeurtenis</strong> is aangepast",
    "A calendar <strong>todo</strong> was modified" : "Een agenda <strong>Te doen</strong> was aangepast",
    "Death of %s" : "Sterfdatum van %s",
    "Contact birthdays" : "Verjaardagen",
    "Calendar:" : "Agenda",
    "Date:" : "Datum",
    "Where:" : "Waar:",
    "Description:" : "Omschrijving:",
    "Untitled event" : "Afspraken zonder naam",
    "_%n year_::_%n years_" : ["%n jaar","%n jaar"],
    "_%n month_::_%n months_" : ["%n maand","%n maanden"],
    "_%n day_::_%n days_" : ["%n dag","%n dagen"],
    "_%n hour_::_%n hours_" : ["%n uur","%n uur"],
    "_%n minute_::_%n minutes_" : ["%n minuut","%n minuten"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (%s geleden)",
    "Calendar: %s" : "Agenda: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beschrijving: %s",
    "Where: %s" : "Waar: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Invitation canceled" : "Uitnodiging geannuleerd",
    "Invitation updated" : "Uitnodiging bijgewerkt",
    "Invitation" : "Uitnodiging",
    "Title:" : "Titel:",
    "Time:" : "Tijd:",
    "Location:" : "Locatie:",
    "Link:" : "Link:",
    "Organizer:" : "Organisator:",
    "Attendees:" : "Deelnemers:",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "More options …" : "Meer opties …",
    "More options at %s" : "Meer opties op %s",
    "Contacts" : "Contactpersonen",
    "System in maintenance mode." : "Server in onderhoudsmodus.",
    "Upgrade needed" : "Upgrade vereist",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Je %s moet worden geconfigureerd voor gebruik van HTTPS om CalDAV en CardDAV met iOS/macOS te kunnen gebruiken.",
    "Configures a CalDAV account" : "Configureert een CalDAV account",
    "Configures a CardDAV account" : "Configureert een CardDAV account",
    "Events" : "Evenementen",
    "Tasks" : "Taken",
    "Untitled task" : "Taak zonder titel",
    "Completed on %s" : "Voltooid op %s",
    "Due on %s by %s" : "Verwacht op %s door %s",
    "Due on %s" : "Verwacht op %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV eindpunt",
    "There was an error updating your attendance status." : "Er trad een fout op bij het bijwerken van je deelnamestatus.",
    "Please contact the organizer directly." : "Neem rechtstreeks contact op met de organisator.",
    "Are you accepting the invitation?" : "Neem je de uitnodiging aan?",
    "Tentative" : "Onder voorbehoud",
    "Save" : "Opslaan",
    "Your attendance was updated successfully." : "Je deelname is succesvol bijgewerkt.",
    "Calendar server" : "Agendaserver",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installeer ook de {calendarappstoreopen}Agenda app{linkclose}, of {calendardocopen}verbind je desktop & mobiel voor synchronisatie ↗{linkclose}.",
    "Send invitations to attendees" : "Verzend uitnodigingen naar deelnemers",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Zorg ervoor dat je de {emailopen}de e-mailserver{linkclose} correct instelt.",
    "Automatically generate a birthday calendar" : "Genereer verjaardagskalender automatisch",
    "Birthday calendars will be generated by a background job." : "Verjaardagkalenders zullen worden gegenereerd in een achtergrond taak.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Hierdoor zullen ze niet meteen beschikbaar zijn na het inschakelen maar zullen na een tijdje verschijnen.",
    "Send notifications for events" : "Versturen meldingen voor afspraken",
    "Notifications are sent via background jobs, so these must occur often enough." : "Meldingen worden via achtergrondtaken verstuurd, dus die moeten vaak genoeg plaatsvinden.",
    "Enable notifications for events via push" : "Inschakelen push-melding voor afspraken",
    "Hello %s," : "Hallo %s,",
    "The meeting »%1$s« with %2$s was canceled." : "De vergadering »%1$s« met %2$s is geannuleerd.",
    "The meeting »%1$s« with %2$s was updated." : "De vergadering »%1$s« met %2$s is bijgewerkt.",
    "%1$s invited you to »%2$s«" : "%1$s heeft je uitgenodigd voor »%2$s«",
    "When:" : "Wanneer:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/nl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Agenda",
    "Todos" : "Te doen",
    "Personal" : "Persoonlijk",
    "{actor} created calendar {calendar}" : "{actor} creëerde agenda {calendar}",
    "You created calendar {calendar}" : "Jij creëerde agenda {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} verwijderde agenda {calendar}",
    "You deleted calendar {calendar}" : "Je verwijderde agenda {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} werkte agenda {calendar} bij",
    "You updated calendar {calendar}" : "Je werkte agenda {calendar} bij",
    "You shared calendar {calendar} as public link" : "Je deelde de agenda {calendar} als openbare link",
    "You removed public link for calendar {calendar}" : "Je verwijderde de openbare link voor de agenda {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} deelde agenda {calendar} met je",
    "You shared calendar {calendar} with {user}" : "Je deelde agenda {calendar} met {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} deelde agenda {calendar} met {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} is gestop de agenda {calendar} met je te delen",
    "You unshared calendar {calendar} from {user}" : "Je stopte met delen agenda {calendar} met {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} stopte met delen agenda {calendar} met {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} stopte het delen van agenda {calendar} met zichzelf",
    "You shared calendar {calendar} with group {group}" : "Je deelde agenda {calendar} met groep {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} deelde agenda {calendar} met groep {group}",
    "You unshared calendar {calendar} from group {group}" : "Je stopte het delen van agenda {calendar} met groep {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} stopte het delen van agenda {calendar} met groep {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creëerde afspraak {event} in agenda {calendar}",
    "You created event {event} in calendar {calendar}" : "Je creëerde afspraak {event} in agenda {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} verwijderde afspraak {event} uit agenda {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Je verwijderde afspraak {event} uit agenda {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} heeft afspraak {event} in agenda {calendar} bijgewerkt",
    "You updated event {event} in calendar {calendar}" : "Je hebt afspraak {event} in agenda {calendar} bijgewerkt",
    "Busy" : "Bezig",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creëerde taak {todo} in lijst {calendar}",
    "You created todo {todo} in list {calendar}" : "Jij creëerde taak {todo} in lijst {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} heeft de taak {todo} uit lijst {calendar} verwijderd",
    "You deleted todo {todo} from list {calendar}" : "Je verwijderde taak {todo} uit lijst {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} heeft taak {todo} bijgewerkt in lijst {calendar}",
    "You updated todo {todo} in list {calendar}" : "Je hebt taak {todo} bijgewerkt in lijst {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} heeft taak {todo} in lijst {calendar} afgewerkt",
    "You solved todo {todo} in list {calendar}" : "Je hebt taak {todo} in lijst {calendar} afgewerkt",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} heropende taak {todo} in lijst {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Je heropende taak {todo} in lijst {calendar}",
    "Calendar and tasks" : "Agenda en taken",
    "A <strong>calendar</strong> was modified" : "Een <strong>agenda</strong> is aangepast",
    "A calendar <strong>event</strong> was modified" : "Een agenda <strong>gebeurtenis</strong> is aangepast",
    "A calendar <strong>todo</strong> was modified" : "Een agenda <strong>Te doen</strong> was aangepast",
    "Contact birthdays" : "Verjaardagen",
    "Death of %s" : "Sterfdatum van %s",
    "Calendar:" : "Agenda",
    "Date:" : "Datum",
    "Where:" : "Waar:",
    "Description:" : "Omschrijving:",
    "Untitled event" : "Afspraken zonder naam",
    "_%n year_::_%n years_" : ["%n jaar","%n jaar"],
    "_%n month_::_%n months_" : ["%n maand","%n maanden"],
    "_%n day_::_%n days_" : ["%n dag","%n dagen"],
    "_%n hour_::_%n hours_" : ["%n uur","%n uur"],
    "_%n minute_::_%n minutes_" : ["%n minuut","%n minuten"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (%s geleden)",
    "Calendar: %s" : "Agenda: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beschrijving: %s",
    "Where: %s" : "Waar: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Invitation canceled" : "Uitnodiging geannuleerd",
    "Invitation updated" : "Uitnodiging bijgewerkt",
    "Invitation" : "Uitnodiging",
    "Title:" : "Titel:",
    "Time:" : "Tijd:",
    "Location:" : "Locatie:",
    "Link:" : "Link:",
    "Organizer:" : "Organisator:",
    "Attendees:" : "Deelnemers:",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "More options …" : "Meer opties …",
    "More options at %s" : "Meer opties op %s",
    "Contacts" : "Contactpersonen",
    "Upgrade needed" : "Upgrade vereist",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Je %s moet worden geconfigureerd voor gebruik van HTTPS om CalDAV en CardDAV met iOS/macOS te kunnen gebruiken.",
    "Configures a CalDAV account" : "Configureert een CalDAV account",
    "Configures a CardDAV account" : "Configureert een CardDAV account",
    "Events" : "Evenementen",
    "Tasks" : "Taken",
    "Untitled task" : "Taak zonder titel",
    "Completed on %s" : "Voltooid op %s",
    "Due on %s by %s" : "Verwacht op %s door %s",
    "Due on %s" : "Verwacht op %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV eindpunt",
    "There was an error updating your attendance status." : "Er trad een fout op bij het bijwerken van je deelnamestatus.",
    "Please contact the organizer directly." : "Neem rechtstreeks contact op met de organisator.",
    "Are you accepting the invitation?" : "Neem je de uitnodiging aan?",
    "Tentative" : "Onder voorbehoud",
    "Save" : "Opslaan",
    "Your attendance was updated successfully." : "Je deelname is succesvol bijgewerkt.",
    "Calendar server" : "Agendaserver",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installeer ook de {calendarappstoreopen}Agenda app{linkclose}, of {calendardocopen}verbind je desktop & mobiel voor synchronisatie ↗{linkclose}.",
    "Send invitations to attendees" : "Verzend uitnodigingen naar deelnemers",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Zorg ervoor dat je de {emailopen}de e-mailserver{linkclose} correct instelt.",
    "Automatically generate a birthday calendar" : "Genereer verjaardagskalender automatisch",
    "Birthday calendars will be generated by a background job." : "Verjaardagkalenders zullen worden gegenereerd in een achtergrond taak.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Hierdoor zullen ze niet meteen beschikbaar zijn na het inschakelen maar zullen na een tijdje verschijnen.",
    "Send notifications for events" : "Versturen meldingen voor afspraken",
    "Notifications are sent via background jobs, so these must occur often enough." : "Meldingen worden via achtergrondtaken verstuurd, dus die moeten vaak genoeg plaatsvinden.",
    "Enable notifications for events via push" : "Inschakelen push-melding voor afspraken",
    "Hello %s," : "Hallo %s,",
    "The meeting »%1$s« with %2$s was canceled." : "De vergadering \"%1$s\" met %2$s is geannuleerd.",
    "The meeting »%1$s« with %2$s was updated." : "De vergadering \"%1$s\" met %2$s is bijgewerkt.",
    "%1$s invited you to »%2$s«" : "%1$s heeft je uitgenodigd voor \"%2$s\"",
    "When:" : "Wanneer:"
},
"nplurals=2; plural=(n != 1);");
